/**
  ******************************************************************************
  * @file    system_read.h
  * @author  sinomcu.com-AE
  * @brief   Header file of system_read.c file.
  * 
  * @note    2022-09-23,updata temperature function describe.
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */

#ifndef __SYSTEM_READ_H
#define __SYSTEM_READ_H

#include "ms32f0xx.h"

#define BID_BASE_ADDRESS              0x1FFFF7A6UL       /*!< BID register address                      */
#define TC_CAL1_ADDRESS               0x1FFFF7B8UL       /*!< V30:TC_CAL1(ADC_Temp1) register address   */              
#define TC_CAL2_ADDRESS               0x1FFFF7BCUL       /*!< Tmp30:TC_CAL2(Sens_Temp1) register address*/
#define VREFINT_CAL_ADDRESS           0x1FFFF7BAUL       /*!< VREFINT_CAL register address              */

/**
  * @brief  Get system memory BID information
  * @note   little endian,2Byte
  *         As an example, 0x0010:1.0.
  * @retval BID
  */
__STATIC_INLINE uint32_t MS32_GetBID(void) {
  return (uint16_t)(READ_REG(*((uint32_t *)BID_BASE_ADDRESS)));
}

// Temperature?= ( Vsense - V30 ) / Avg_Slope + Tmp30
// Vsenser:Temperature sener voltage
// Avg_slope:4.3mv/?;datasheet V1.1.0,page41,table 6.3.14 

/**
  * @brief  Get system memory TC_CAL1(ADC_Temp1) information
  * @note   V30:TBDV,TBD~TBD;datasheet V1.1.0 need to updata
  * @retval Temperature senser orignal ADC data at TBD?,VDD 3.3V+-10mv
  */
__STATIC_INLINE uint32_t MS32_GetV30(void) {
  return (uint16_t)(READ_REG(*((uint32_t *)TC_CAL1_ADDRESS)));
}

/**
  * @brief  Get system memory TC_CAL2(Sens_Temp1) information
  * @note   Temperature =TC_CAL2(Sens_Temp1) *0.0625
  * @retval TC_CAL2(Sens_Temp1)(TMP275 value)
  */
__STATIC_INLINE uint32_t MS32_GetTmp30(void) {
  return (uint16_t)(READ_REG(*((uint32_t *)TC_CAL2_ADDRESS)));
}

/**
  * @brief  Get system memory VREFINT_CAL information
  * @note   Vrefint:1.123V,1.16~1.25V;datasheet V1.1.0,page24,table 6.3.4 
  * @retval BID
  */
__STATIC_INLINE uint32_t MS32_VREFINT(void) {
  return (uint16_t)(READ_REG(*((uint32_t *)VREFINT_CAL_ADDRESS)));
}

#endif /* __SYSTEM_READ_H */ 

/******************************** END OF FILE *********************************/
